"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.joulesToFtLbs = exports.ftLbsToJoules = exports.poundsToOunces = exports.ouncesToPounds = void 0;
const errorsList_1 = require("../errorsList");
/**
 * @description Converts ounces to pounds
 * @param ounces
 * @returns pounds conversion
 * @example ouncesToPounds(16) //returns 1
 * ouncesToPounds(32) //returns 2
 * ouncesToPounds("16") //throws error
 * ouncesToPounds(null) //throws error
 */
function ouncesToPounds(ounces) {
    if (typeof ounces === "number") {
        return ounces / 16;
    }
    throw new Error(errorsList_1.errorsList.paramNotType("ouncesToPounds", "ounces", ounces, "number"));
}
exports.ouncesToPounds = ouncesToPounds;
/**
 * @description Converts pounds to ounces
 * @param pounds
 * @returns ounces conversion
 * @example poundsToOunces(1) //returns 16
 * poundsToOunces(2) //returns 32
 * poundsToOunces("2") //throws error
 * poundsToOunces(null) //throws error
 */
function poundsToOunces(pounds) {
    if (typeof pounds === "number") {
        return pounds * 16;
    }
    throw new Error(errorsList_1.errorsList.paramNotType("poundsToOunces", "pounds", pounds, "number"));
}
exports.poundsToOunces = poundsToOunces;
/**
 * @description Converts Foot-pounds to Joules
 * @param ftLbs
 * @returns Joules conversion
 * @example  ftLbsToJoules(1) //return 1.35581794833508
 * ftLbsToJoules("1") //throws error
 * ftLbsToJoules(null) //throws error
 */
function ftLbsToJoules(ftLbs) {
    if (typeof ftLbs === "number") {
        return ftLbs * 1.35581794833508;
    }
    throw new Error(errorsList_1.errorsList.paramNotType("ftLbsToJoules", "ftLbs", ftLbs, "number"));
}
exports.ftLbsToJoules = ftLbsToJoules;
/**
 * @description Converts Joules to Foot-pounds
 * @param joules
 * @returns Foot-Pounds conversion
 * @example joulesToFtLbs(1) //returns 0.7375621492752636
 * joulesToFtLbs("1") //throws error
 * joulesToFtLbs(null) //throws error
 */
function joulesToFtLbs(joules) {
    if (typeof joules === "number") {
        return joules / 1.35581794833508;
    }
    throw new Error(errorsList_1.errorsList.paramNotType("joulesToFtLbs", "joules", joules, "number"));
}
exports.joulesToFtLbs = joulesToFtLbs;
//# sourceMappingURL=UnitsConversion.js.map