"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @description Calculate the kinetic energy of a bullet
 * @returns kineticEnergy in Foot-Pounds
 * @example kineticEnergy({bulletWeightGrains: 62, velocityFps: 3050})//returns {kineticEnergyFtLbs: 1280.4371764246198, error: false, errorMessage: null}
 * kineticEnergy({bulletWeightGrains: 0, velocityFps: 3050})//returns { kineticEnergyFtLbs: null, error: true; errorMessage: "kineticEnergy Error(s): bulletWeightGrains param must be of type number and greater than 0."}
 * kineticEnergy({bulletWeightGrains: 62, velocityFps: undefined})//returns { kineticEnergyFtLbs: null, error: true; errorMessage: "kineticEnergy Error(s): velocityFps param must be of type number and greater than 0."}
 */
function kineticEnergy(kineticEnergyParams) {
    let { bulletWeightGrains, velocityFps } = kineticEnergyParams;
    let error = false;
    let errorMessage = `kineticEnergy Error(s):`;
    if (typeof bulletWeightGrains !== "number" || bulletWeightGrains <= 0) {
        error = true;
        errorMessage +=
            "\nbulletWeightGrains param must be of type number and greater than 0.";
    }
    if (typeof velocityFps !== "number" || velocityFps < 0) {
        error = true;
        errorMessage += "\nvelocityFps param must be of type number and greater than 0.";
    }
    if (error)
        return { kineticEnergyFtLbs: null, error, errorMessage };
    let bulletMass = bulletWeightGrains / (7000 * 32.174);
    let kineticEnergy = (bulletMass * Math.pow(velocityFps, 2)) / 2;
    return { kineticEnergyFtLbs: kineticEnergy, error: false, errorMessage: null };
}
exports.default = kineticEnergy;
//# sourceMappingURL=kineticEnergy.js.map